decrypt_repo

Function decrypt_repo 

pub fn decrypt_repo(repo: &'static Repo, paths: &[PathBuf]) -> Result<()>
Decrypt given files in the repo. If no paths are given, decrypt all files in the repo’s crypt list.

The salt+file_id of each successfully parsed encrypted file is captured via an mpsc channel so that a subsequent encrypt can reproduce identical ciphertext.