pub fn create_writer(repo_path: &Path) -> (SaltCacheSender, SaltCacheSaver)Expand description
Create a paired sender/saver for collecting cache entries.
The sender is Sync and can be shared across rayon threads. The saver
should be kept on the main thread and .save()d after parallel work
completes. If .save() is not called, SaltCacheSaver::drop will
persist any buffered entries as a safety net.