pub struct CachedEntry {
pub salt: [u8; 16],
pub file_id: [u8; 16],
}Expand description
A cached header entry for deterministic re-encryption.
Stores the salt (for key derivation) and file_id (for nonce derivation) so
that re-encrypting the same plaintext produces byte-identical ciphertext.
Fields
salt: [u8; 16]file_id: [u8; 16]Trait Implementations
Sourceimpl Archive for CachedEntry
impl Archive for CachedEntry
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCachedEntry
type Archived = ArchivedCachedEntry
The archived representation of this type. Read more
Sourcetype Resolver = CachedEntryResolver
type Resolver = CachedEntryResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for CachedEntry
impl Clone for CachedEntry
Sourcefn clone(&self) -> CachedEntry
fn clone(&self) -> CachedEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CachedEntry
impl Debug for CachedEntry
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CachedEntry, __D> for Archived<CachedEntry>
impl<__D: Fallible + ?Sized> Deserialize<CachedEntry, __D> for Archived<CachedEntry>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CachedEntry, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CachedEntry, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for CachedEntry
Sourceimpl PartialEq for CachedEntry
impl PartialEq for CachedEntry
Sourcefn eq(&self, other: &CachedEntry) -> bool
fn eq(&self, other: &CachedEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CachedEntry