is_file_encrypted

Function is_file_encrypted 

pub fn is_file_encrypted(path: &Path) -> Result<bool>
Check whether a single file has a valid GITSE encrypted header. Returns an error if the file cannot be read (IO error).