pub fn list_files( paths: impl IntoIterator<Item = impl AsRef<Path>>, cwd: impl AsRef<Path>, ) -> Vec<PathBuf>
If the given path is a file, return the file name. Otherwise, return the recursive file name in the given dir.